@@ -73,6 +73,7 @@ class ColumnBase:
         self.additional_columns = []
         self.kwargs = kwargs
         self.replace_list = []
+        self.blank = None
         if not hasattr(self, 'row_result'):
             self.row_result = MethodType(self.__row_result, self)
         self.setup_kwargs(kwargs)
@@ -115,6 +116,8 @@ class ColumnBase:
         elif isinstance(fields, (list, tuple)):
             self.options['field_array'] = True
             self._field = [self.model_path + o for o in fields]
+            if not hasattr(self, 'row_result') or type(self.row_result.__self__) == ColumnBase:
+                self.row_result = MethodType(self.__list_row_result, self)
         else:
             self._field = self.model_path + fields
 
@@ -148,12 +151,19 @@ class ColumnBase:
     def setup_results(self, request, all_results):
         return
 
+    @staticmethod
+    def __list_row_result(self, data_dict, _page_results):
+        return [data_dict.get(f) for f in self.field]
+
     @staticmethod
     def __row_result(self, data_dict, _page_results):
-        if isinstance(self.field, (list, tuple)):
-            return [data_dict.get(f) for f in self.field]
         if self.options.get('choices'):
             return self.options['choices'].get(data_dict.get(self.field))
+        if self.blank:
+            ret_val = data_dict.get(self.field)
+            if not ret_val:
+                return self.blank
+            return ret_val
         return data_dict.get(self.field)
 
     def style(self):
@@ -286,6 +296,9 @@ class ManyToManyColumn(DatatableColumn):
     def row_result(self, data_dict, page_results):
         return page_results['m2m' + self.column_name].get(data_dict['id'], self.blank)
 
+    def get_lookup(self, fields):
+        return list(self.related_model.objects.values_list('pk', fields[-1]))
+
     def __init__(self, *,  html=' %1% ', **kwargs):
         if not self.initialise(locals()):
             return
@@ -293,6 +306,7 @@ class ManyToManyColumn(DatatableColumn):
         fields = self.field.split('__')
         if not inspect.isclass(self.model):
             raise DatatableColumnError('ManyToManyColumn must have model set')
+        # noinspection PyProtectedMember
         connecting_field = self.model._meta.get_field(fields[-2])
         self.related_model = connecting_field.related_model
         if hasattr(connecting_field, 'field'):
@@ -302,7 +316,7 @@ class ManyToManyColumn(DatatableColumn):
             self.field_id = fields[-2] + '__pk'
             self.reverse = False
         self.field = None
-        self.options['lookup'] = kwargs.pop('lookup', list(self.related_model.objects.values_list('pk', fields[-1])))
+        self.options['lookup'] = kwargs.pop('lookup', self.get_lookup(fields=fields))
         if 'blank' in kwargs:
             self.options['lookup'].append((-1, kwargs.pop('blank')))
             self.blank = [-1]
@@ -352,6 +366,10 @@ class CurrencyPenceColumn(ColumnBase):
         except KeyError:
             return
 
+    def setup_kwargs(self, kwargs):
+        super().setup_kwargs(kwargs)
+        self.column_defs = {'className': 'dt-right'}
+
 
 class CurrencyColumn(ColumnBase):
 
@@ -361,6 +379,10 @@ class CurrencyColumn(ColumnBase):
         except KeyError:
             return
 
+    def setup_kwargs(self, kwargs):
+        super().setup_kwargs(kwargs)
+        self.column_defs = {'className': 'dt-right'}
+
 
 class BooleanColumn(ColumnBase):
 
@@ -395,7 +417,7 @@ class CallableColumn(DatatableColumn):
 
     def row_result(self, data_dict, _page_results):
         fake_object = type('fake', (), {k[len(self.model_path):]: v
-                                        for k,v in data_dict.items()
+                                        for k, v in data_dict.items()
                                         if k.startswith(self.model_path)})
         return self.object_function(fake_object)
 
