@@ -125,6 +125,7 @@ class DatatableTable:
         self.js_filter_list = []
         self.plugins = []
         self.omit_columns = []
+        self.datatable_template = 'datatables/table.html'
 
         if table_classes:
             self.table_classes = table_classes
@@ -149,6 +150,10 @@ class DatatableTable:
     def add_plugin(self, plugin, *args, **kwargs):
         self.plugins.append(plugin(self, *args, **kwargs))
 
+    @staticmethod
+    def extra_filters(query):
+        return query
+
     def get_query(self, **_kwargs):
         annotations = {}
         for c in self.columns:
@@ -164,6 +169,7 @@ class DatatableTable:
             query = query.distinct(*self.distinct)
         if self.max_records:
             query = query[:self.max_records]
+        query = self.extra_filters(query=query)
         return query
 
     def sort(self, *columns):
@@ -217,7 +223,7 @@ class DatatableTable:
         rendered_strings = []
         for p in self.plugins:
             rendered_strings.append(p.render())
-        rendered_strings.append(render_to_string('datatables/table.html', {'datatable': self}))
+        rendered_strings.append(render_to_string(self.datatable_template, {'datatable': self}))
         return ''.join(rendered_strings)
 
     def setup_column_id(self):
