@@ -1,6 +1,14 @@
 from django.urls import reverse
 DUMMY_ID = 999999
 
+simple_table = {
+    'dom': 't',
+    'no_col_search': True,
+    'nofooter': True,
+    'pageLength': 400,
+    'stateSave': False
+}
+
 
 def row_button(command, button_text, *, function='Html', button_classes='btn btn-sm', **kwargs):
     rb = {
@@ -12,11 +20,8 @@ def row_button(command, button_text, *, function='Html', button_classes='btn btn
     return rb
 
 
-def render_replace(*, column, var='%1%', html=None):
-    if html:
-        return {'var': var, 'column': column, 'html': html, 'function': 'Replace'}
-    else:
-        return {'var': var, 'column': column, 'function': 'Replace'}
+def render_replace(*, var='%1%', **kwargs):
+    return dict(var=var, function='Replace', **kwargs)
 
 
 def get_url(url_name):
