@@ -12,6 +12,10 @@ if (typeof django_datatables === 'undefined') {
 
         var utilities = {
 
+            numberWithCommas: function(x, decimal_places=0) {
+                return x.toFixed(decimal_places).replace(/\B(?=(\d{3})+(?!\d))/g, ",");
+            },
+
             getCookie: function (name) {
                 var cookieValue = null;
                 if (document.cookie && document.cookie !== '') {
@@ -383,8 +387,51 @@ if (typeof django_datatables === 'undefined') {
                 } else {
                     params.index = 0
                 }
+            } else if  (params.column === undefined) {
+                params.column = column
+            }
+            if (params.var != undefined) {
+                if (Array.isArray(params.var)) {
+                    this.reg_exp = []
+                    for (var i = 0; i < params.var.length; i++) {
+                        this.reg_exp.push(RegExp(params.var[i], 'g'))
+                    }
+                } else {
+                    this.reg_exp = RegExp(params.var, 'g')
+                }
+            }
+            if (params.null_value === undefined){
+                this.null_value = ''
+            }
+            else{
+                this.null_value = params.null_value
             }
             this.params = params
+            if (table.initsetup.colOptions[this.column].lookup != undefined) {
+                this.lookup = {}
+                for (var lv = 0; lv < table.initsetup.colOptions[this.column].lookup.length; lv++) {
+                    this.lookup[table.initsetup.colOptions[this.column].lookup[lv][0]] = table.initsetup.colOptions[this.column].lookup[lv][1]
+                }
+            }
+        }
+
+        BaseProcessAjaxData.prototype.determine_value = function (value) {
+            if (this.field_array && value != null) {
+                return value[this.params.index]
+            }
+            return value
+        }
+
+        BaseProcessAjaxData.prototype.determine_html = function (value, current) {
+            if (value == null) {
+                return this.null_value;
+            }
+            if (this.params.gte != undefined && value >= this.params.gte){
+                return this.params.alt_html
+            }
+            if (this.params.html == undefined)
+                return String(current)
+            return this.params.html
         }
 
         BaseProcessAjaxData.prototype.process = function (column_data, type, row, meta) {
@@ -406,7 +453,6 @@ if (typeof django_datatables === 'undefined') {
         var data_processing = {
             Row: function (column, params, table) {
                 django_datatables.BaseProcessAjaxData.call(this, column, params, table)
-                this.reg_exp = RegExp(params.var, 'g')
                 if (params.html === undefined) {
                     this.convert = function (current, value, meta, row) {
                         return current.replace(params.var, meta.settings.rowId(row))
@@ -419,47 +465,27 @@ if (typeof django_datatables === 'undefined') {
             },
 
             Replace: function (column, params, table) {
-                this.reg_exp = RegExp(params.var, 'g')
                 django_datatables.BaseProcessAjaxData.call(this, column, params, table)
-                if (this.params.null_value === undefined){
-                    this.null_value = ''
-                }
-                else{
-                    this.null_value = this.params.null_value
-                }
                 this.convert = function (current, value) {
-                    var replacement = value
-                    if (this.field_array && replacement != null){
-                        replacement = value[params.index]
-                    }
-                    if (replacement == null){
-                        return this.null_value;
-                    }
-                    if (params.html === undefined) {
-                        return current.replace(this.reg_exp, replacement)
-                    } else {
-                        return params.html.replace(this.reg_exp, replacement)
-                    }
+                    value = this.determine_value(value)
+                    return this.determine_html(value, current).replace(this.reg_exp, value)
                 }.bind(this)
             },
 
             ReplaceLookup: function (column, params, table) {
                 django_datatables.BaseProcessAjaxData.call(this, column, params, table)
-                this.reg_exp = RegExp(params.var, 'g')
-                if (params.column === undefined) {
-                    params.column = column
-                }
-                params.lookup = {}
-                for (var lv = 0; lv < table.initsetup.colOptions[params.column].lookup.length; lv++) {
-                    params.lookup[table.initsetup.colOptions[params.column].lookup[lv][0]] = table.initsetup.colOptions[params.column].lookup[lv][1]
-                }
-                if (params.html === undefined) {
+                if (Array.isArray(this.reg_exp)) {
                     this.convert = function (current, value) {
-                        return this.params.lookup[value]
-                    }.bind(this)
+                        var html = this.params.html
+                        for (var v = 0; v < this.reg_exp.length; v++) {
+                            html = html.replace(this.reg_exp[v], this.lookup[value][v])
+                        }
+                        return html
+                    }
                 } else {
                     this.convert = function (current, value) {
-                        return this.params.html.replace(this.reg_exp, this.params.lookup[value])
+                        value = this.determine_value(value)
+                        return this.determine_html(value, current).replace(this.reg_exp, this.lookup[value])
                     }.bind(this)
                 }
             },
@@ -489,11 +515,37 @@ if (typeof django_datatables === 'undefined') {
 
             },
 
-            MergeArray: function (column, params) {
-                this.column = column
-                this.process = function (new_row, row) {
-                    console.log(new_row)
-                    new_row[this.column] = new_row[this.column].join(' ')
+            MergeArray: function (column, params, table) {
+                django_datatables.BaseProcessAjaxData.call(this, column, params, table)
+                if (params.separator == undefined){
+                    this.separator = ' '
+                } else{
+                    this.separator = params.separator
+                }
+                if (params.default){
+                    this.convert = function (current, row) {
+                        try {
+                            return_val = current.slice(0, current.length - 1).filter(function (l) {
+                                return l != '' && l != null;
+                            }).join(this.separator)
+                        } catch (e) {
+                            return ''
+                        }
+                        if (return_val == '' && current[current.length - 1] != null && current[current.length - 1].length > 0) {
+                            return current[current.length - 1]
+                        }
+                        return return_val
+                    }.bind(this)
+                } else{
+                    this.convert = function (current, row) {
+                        try {
+                            return current.filter(function (l) {
+                                return l != '' && l != null;
+                            }).join(this.separator)
+                        } catch (e) {
+                            return ''
+                        }
+                    }.bind(this)
                 }
             }
         }
@@ -561,8 +613,14 @@ if (typeof django_datatables === 'undefined') {
             }
             if (tablesetup.tableOptions.data === undefined) {
                 var csrf = django_datatables.utilities.getCookie('csrftoken');
+                var url
+                if (window.location.search == '')
+                    url = '?datatable-data=true'
+                else{
+                    url = window.location.search + '&datatable-data=true'
+                }
                 dataTable_setup.ajax = {
-                    'url': '?datatable-data=true',
+                    'url': url,
                     "type": "POST",
                     "data": {"csrfmiddlewaretoken": csrf, table_id: html_id}
                 }
@@ -574,13 +632,14 @@ if (typeof django_datatables === 'undefined') {
                 }
             }
             Object.assign(dataTable_setup, tablesetup.tableOptions)
-            Object.assign(dataTable_setup, django_datatables.setup[html_id].datatable_setup)
-
+            init_setup(html_id)
+            if (django_datatables.setup[html_id].datatable_setup != undefined){
+                Object.assign(dataTable_setup, django_datatables.setup[html_id].datatable_setup)
+            }
             if (typeof (tablesetup.tableOptions.rowGroup) != 'undefined') {
                 dataTable_setup['rowGroup'] =
                     {
                         dataSrc: tablesetup.field_ids.indexOf(tablesetup.tableOptions.rowGroup.dataSrc),
-                        /*
                         endRender: function (rows, group) {
                             sums = Array(rows.data()[0].length).fill('')
                             tablesetup.tableOptions.rowGroup.sumColumns.forEach(
@@ -594,10 +653,9 @@ if (typeof django_datatables === 'undefined') {
                                 })
                             sums_row = ''
                             for (c = 0; c < sums.length; c++) {
-                                if (tablesetup.columnDefs[c].hidden != true) {
+                                if (tablesetup.colOptions[c].hidden != true) {
                                     if (typeof (sums[c]) == 'number') {
-                                        sums_row += '<td class="pr-4">' + sums[c].toFixed(2);
-                                        +'</td>'
+                                        sums_row += '<td class="dt-right">' + sums[c].toFixed(2) + '</td>'
                                     } else {
                                         sums_row += '<td></td>'
                                     }
@@ -607,7 +665,6 @@ if (typeof django_datatables === 'undefined') {
                         },
                         startClassName: 'table-info font-weight-bold',
                         endClassName: 'font-weight-bold white text-right'
-                        */
                     }
             }
 
@@ -643,18 +700,24 @@ if (typeof django_datatables === 'undefined') {
         PythonTable.prototype.init_filters = function () {
             this.table.api().rows().data().each(function (row) {
                 this.filters.forEach(function (filter) {
-                    filter.filter_calcs.init_calcs(row)
+                    if (filter.filter_calcs != undefined) {
+                        filter.filter_calcs.init_calcs(row)
+                    }
                 })
             }.bind(this))
         }
 
         PythonTable.prototype.proc_filters = function () {
             this.filters.forEach(function (filter) {
-                filter.filter_calcs.clear_calcs()
+                if (filter.filter_calcs != undefined) {
+                    filter.filter_calcs.clear_calcs()
+                }
             })
             this.table.api().rows({"filter": "applied"}).data().each(function (row) {
                 this.filters.forEach(function (filter) {
-                    filter.filter_calcs.add_calcs(row)
+                    if (filter.filter_calcs != undefined) {
+                        filter.filter_calcs.add_calcs(row)
+                    }
                 })
             }.bind(this))
         }
@@ -727,11 +790,6 @@ function rep_options(html, option_dict) {
 }
 
 
-function numberWithCommas(x) {
-    return x.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ",");
-}
-
-
 $(document).ready(function () {
     $.fn.dataTable.moment("DD/MM/YYYY");
 });
